'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _glamor = require('glamor');

var _htmlTagNames = require('html-tag-names');

var _htmlTagNames2 = _interopRequireDefault(_htmlTagNames);

var _svgTagNames = require('svg-tag-names');

var _svgTagNames2 = _interopRequireDefault(_svgTagNames);

var _objectAssign = require('object-assign');

var _objectAssign2 = _interopRequireDefault(_objectAssign);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

/*
 * This works just like React createElement, but allows us to pass default styling
 * as well as gives us a "css" prop that we can use to add overrides later on
 *
 * MyStyledComponent = createStyledElement(MyComponent)({
 *   color: '#b4da55'
 * })
 *
 */
function createStyledElement(component, props, children) {
  return function () {
    for (var _len = arguments.length, chunks = Array(_len), _key = 0; _key < _len; _key++) {
      chunks[_key] = arguments[_key];
    }

    var classNames = chunks.map(function (chunk) {
      return chunk ? (0, _glamor.css)(chunk) : '';
    });

    if (props) {
      var _extends2;

      var innerRef = props.innerRef,
          forwardRef = props.forwardRef,
          css = props.css,
          className = props.className,
          restProps = _objectWithoutProperties(props, ['innerRef', 'forwardRef', 'css', 'className']);

      if (css) {
        classNames.push((0, _glamor.css)(css));
      }

      if (className) {
        classNames.push(className);
      }

      return (0, _react.createElement)(component, _extends((_extends2 = {}, _defineProperty(_extends2, forwardRef ? 'innerRef' : 'ref', innerRef), _defineProperty(_extends2, 'className', classNames.join(' ').trim()), _extends2), restProps), restProps.children || children);
    } else {
      return function (_ref) {
        var _extends3;

        var innerRef = _ref.innerRef,
            forwardRef = _ref.forwardRef,
            css = _ref.css,
            _ref$className = _ref.className,
            className = _ref$className === undefined ? '' : _ref$className,
            restProps = _objectWithoutProperties(_ref, ['innerRef', 'forwardRef', 'css', 'className']);

        var glamorClass = css ? (0, _glamor.css)(css) : '';

        return (0, _react.createElement)(component, _extends((_extends3 = {}, _defineProperty(_extends3, forwardRef ? 'innerRef' : 'ref', innerRef), _defineProperty(_extends3, 'className', classNames.concat(glamorClass, className).join(' ').trim()), _extends3), restProps));
      };
    }
  };
}

/*
 * repurposed from Glamorous:
 * https://github.com/paypal/glamorous/blob/master/src/index.js#L26-L45
 *
 * This creates a styledElement component for each DOM element so you can simply do:
 * <createStyledElement.Div
 *   css={{
 *     color: 'green'
 *   }}
 * >
 *   I'm green!
 * </createStyledElement.Div>
 *
 */
var capitalize = function capitalize(str) {
  return str.charAt(0).toUpperCase() + str.substring(1);
};
var domElements = _htmlTagNames2.default.concat(_svgTagNames2.default).filter(function (tag, index, array) {
  return array.indexOf(tag) === index;
});

(0, _objectAssign2.default)(createStyledElement, domElements.reduce(function (components, tag) {
  var capitalTag = capitalize(tag);
  components[capitalTag] = createStyledElement(tag)();
  components[capitalTag].displayName = 'Styled' + capitalTag;
  return components;
}, {}));

exports.default = createStyledElement;
exports.A = createStyledElement.A;
exports.Abbr = createStyledElement.Abbr;
exports.Acronym = createStyledElement.Acronym;
exports.Address = createStyledElement.Address;
exports.Applet = createStyledElement.Applet;
exports.Area = createStyledElement.Area;
exports.Article = createStyledElement.Article;
exports.Aside = createStyledElement.Aside;
exports.Audio = createStyledElement.Audio;
exports.B = createStyledElement.B;
exports.Base = createStyledElement.Base;
exports.Basefont = createStyledElement.Basefont;
exports.Bdi = createStyledElement.Bdi;
exports.Bdo = createStyledElement.Bdo;
exports.Bgsound = createStyledElement.Bgsound;
exports.Big = createStyledElement.Big;
exports.Blink = createStyledElement.Blink;
exports.Blockquote = createStyledElement.Blockquote;
exports.Body = createStyledElement.Body;
exports.Br = createStyledElement.Br;
exports.Button = createStyledElement.Button;
exports.Canvas = createStyledElement.Canvas;
exports.Caption = createStyledElement.Caption;
exports.Center = createStyledElement.Center;
exports.Cite = createStyledElement.Cite;
exports.Code = createStyledElement.Code;
exports.Col = createStyledElement.Col;
exports.Colgroup = createStyledElement.Colgroup;
exports.Command = createStyledElement.Command;
exports.Content = createStyledElement.Content;
exports.Data = createStyledElement.Data;
exports.Datalist = createStyledElement.Datalist;
exports.Dd = createStyledElement.Dd;
exports.Del = createStyledElement.Del;
exports.Details = createStyledElement.Details;
exports.Dfn = createStyledElement.Dfn;
exports.Dialog = createStyledElement.Dialog;
exports.Dir = createStyledElement.Dir;
exports.Div = createStyledElement.Div;
exports.Dl = createStyledElement.Dl;
exports.Dt = createStyledElement.Dt;
exports.Element = createStyledElement.Element;
exports.Em = createStyledElement.Em;
exports.Embed = createStyledElement.Embed;
exports.Fieldset = createStyledElement.Fieldset;
exports.Figcaption = createStyledElement.Figcaption;
exports.Figure = createStyledElement.Figure;
exports.Font = createStyledElement.Font;
exports.Footer = createStyledElement.Footer;
exports.Form = createStyledElement.Form;
exports.Frame = createStyledElement.Frame;
exports.Frameset = createStyledElement.Frameset;
exports.H1 = createStyledElement.H1;
exports.H2 = createStyledElement.H2;
exports.H3 = createStyledElement.H3;
exports.H4 = createStyledElement.H4;
exports.H5 = createStyledElement.H5;
exports.H6 = createStyledElement.H6;
exports.Head = createStyledElement.Head;
exports.Header = createStyledElement.Header;
exports.Hgroup = createStyledElement.Hgroup;
exports.Hr = createStyledElement.Hr;
exports.Html = createStyledElement.Html;
exports.I = createStyledElement.I;
exports.Iframe = createStyledElement.Iframe;
exports.Image = createStyledElement.Image;
exports.Img = createStyledElement.Img;
exports.Input = createStyledElement.Input;
exports.Ins = createStyledElement.Ins;
exports.Isindex = createStyledElement.Isindex;
exports.Kbd = createStyledElement.Kbd;
exports.Keygen = createStyledElement.Keygen;
exports.Label = createStyledElement.Label;
exports.Legend = createStyledElement.Legend;
exports.Li = createStyledElement.Li;
exports.Link = createStyledElement.Link;
exports.Listing = createStyledElement.Listing;
exports.Main = createStyledElement.Main;
exports.MapTag = createStyledElement.MapTag;
exports.Mark = createStyledElement.Mark;
exports.Marquee = createStyledElement.Marquee;
exports.MathTag = createStyledElement.MathTag;
exports.Menu = createStyledElement.Menu;
exports.Menuitem = createStyledElement.Menuitem;
exports.Meta = createStyledElement.Meta;
exports.Meter = createStyledElement.Meter;
exports.Multicol = createStyledElement.Multicol;
exports.Nav = createStyledElement.Nav;
exports.Nextid = createStyledElement.Nextid;
exports.Nobr = createStyledElement.Nobr;
exports.Noembed = createStyledElement.Noembed;
exports.Noframes = createStyledElement.Noframes;
exports.Noscript = createStyledElement.Noscript;
exports.ObjectTag = createStyledElement.ObjectTag;
exports.Ol = createStyledElement.Ol;
exports.Optgroup = createStyledElement.Optgroup;
exports.Option = createStyledElement.Option;
exports.Output = createStyledElement.Output;
exports.P = createStyledElement.P;
exports.Param = createStyledElement.Param;
exports.Picture = createStyledElement.Picture;
exports.Plaintext = createStyledElement.Plaintext;
exports.Pre = createStyledElement.Pre;
exports.Progress = createStyledElement.Progress;
exports.Q = createStyledElement.Q;
exports.Rb = createStyledElement.Rb;
exports.Rbc = createStyledElement.Rbc;
exports.Rp = createStyledElement.Rp;
exports.Rt = createStyledElement.Rt;
exports.Rtc = createStyledElement.Rtc;
exports.Ruby = createStyledElement.Ruby;
exports.S = createStyledElement.S;
exports.Samp = createStyledElement.Samp;
exports.Script = createStyledElement.Script;
exports.Section = createStyledElement.Section;
exports.Select = createStyledElement.Select;
exports.Shadow = createStyledElement.Shadow;
exports.Slot = createStyledElement.Slot;
exports.Small = createStyledElement.Small;
exports.Source = createStyledElement.Source;
exports.Spacer = createStyledElement.Spacer;
exports.Span = createStyledElement.Span;
exports.Strike = createStyledElement.Strike;
exports.Strong = createStyledElement.Strong;
exports.Style = createStyledElement.Style;
exports.Sub = createStyledElement.Sub;
exports.Summary = createStyledElement.Summary;
exports.Sup = createStyledElement.Sup;
exports.Svg = createStyledElement.Svg;
exports.Table = createStyledElement.Table;
exports.Tbody = createStyledElement.Tbody;
exports.Td = createStyledElement.Td;
exports.Template = createStyledElement.Template;
exports.Textarea = createStyledElement.Textarea;
exports.Tfoot = createStyledElement.Tfoot;
exports.Th = createStyledElement.Th;
exports.Thead = createStyledElement.Thead;
exports.Time = createStyledElement.Time;
exports.Title = createStyledElement.Title;
exports.Tr = createStyledElement.Tr;
exports.Track = createStyledElement.Track;
exports.Tt = createStyledElement.Tt;
exports.U = createStyledElement.U;
exports.Ul = createStyledElement.Ul;
exports.Var = createStyledElement.Var;
exports.Video = createStyledElement.Video;
exports.Wbr = createStyledElement.Wbr;
exports.Xmp = createStyledElement.Xmp;
exports.AltGlyph = createStyledElement.AltGlyph;
exports.AltGlyphDef = createStyledElement.AltGlyphDef;
exports.AltGlyphItem = createStyledElement.AltGlyphItem;
exports.Animate = createStyledElement.Animate;
exports.AnimateColor = createStyledElement.AnimateColor;
exports.AnimateMotion = createStyledElement.AnimateMotion;
exports.AnimateTransform = createStyledElement.AnimateTransform;
exports.Animation = createStyledElement.Animation;
exports.Circle = createStyledElement.Circle;
exports.ClipPath = createStyledElement.ClipPath;
exports.ColorProfile = createStyledElement.ColorProfile;
exports.Cursor = createStyledElement.Cursor;
exports.Defs = createStyledElement.Defs;
exports.Desc = createStyledElement.Desc;
exports.Discard = createStyledElement.Discard;
exports.Ellipse = createStyledElement.Ellipse;
exports.FeBlend = createStyledElement.FeBlend;
exports.FeColorMatrix = createStyledElement.FeColorMatrix;
exports.FeComponentTransfer = createStyledElement.FeComponentTransfer;
exports.FeComposite = createStyledElement.FeComposite;
exports.FeConvolveMatrix = createStyledElement.FeConvolveMatrix;
exports.FeDiffuseLighting = createStyledElement.FeDiffuseLighting;
exports.FeDisplacementMap = createStyledElement.FeDisplacementMap;
exports.FeDistantLight = createStyledElement.FeDistantLight;
exports.FeDropShadow = createStyledElement.FeDropShadow;
exports.FeFlood = createStyledElement.FeFlood;
exports.FeFuncA = createStyledElement.FeFuncA;
exports.FeFuncB = createStyledElement.FeFuncB;
exports.FeFuncG = createStyledElement.FeFuncG;
exports.FeFuncR = createStyledElement.FeFuncR;
exports.FeGaussianBlur = createStyledElement.FeGaussianBlur;
exports.FeImage = createStyledElement.FeImage;
exports.FeMerge = createStyledElement.FeMerge;
exports.FeMergeNode = createStyledElement.FeMergeNode;
exports.FeMorphology = createStyledElement.FeMorphology;
exports.FeOffset = createStyledElement.FeOffset;
exports.FePointLight = createStyledElement.FePointLight;
exports.FeSpecularLighting = createStyledElement.FeSpecularLighting;
exports.FeSpotLight = createStyledElement.FeSpotLight;
exports.FeTile = createStyledElement.FeTile;
exports.FeTurbulence = createStyledElement.FeTurbulence;
exports.Filter = createStyledElement.Filter;
exports.FontFace = createStyledElement.FontFace;
exports.FontFaceFormat = createStyledElement.FontFaceFormat;
exports.FontFaceName = createStyledElement.FontFaceName;
exports.FontFaceSrc = createStyledElement.FontFaceSrc;
exports.FontFaceUri = createStyledElement.FontFaceUri;
exports.ForeignObject = createStyledElement.ForeignObject;
exports.G = createStyledElement.G;
exports.Glyph = createStyledElement.Glyph;
exports.GlyphRef = createStyledElement.GlyphRef;
exports.Handler = createStyledElement.Handler;
exports.Hatch = createStyledElement.Hatch;
exports.Hatchpath = createStyledElement.Hatchpath;
exports.Hkern = createStyledElement.Hkern;
exports.Line = createStyledElement.Line;
exports.LinearGradient = createStyledElement.LinearGradient;
exports.Listener = createStyledElement.Listener;
exports.Marker = createStyledElement.Marker;
exports.Mask = createStyledElement.Mask;
exports.Mesh = createStyledElement.Mesh;
exports.Meshgradient = createStyledElement.Meshgradient;
exports.Meshpatch = createStyledElement.Meshpatch;
exports.Meshrow = createStyledElement.Meshrow;
exports.Metadata = createStyledElement.Metadata;
exports.MissingGlyph = createStyledElement.MissingGlyph;
exports.Mpath = createStyledElement.Mpath;
exports.Path = createStyledElement.Path;
exports.Pattern = createStyledElement.Pattern;
exports.Polygon = createStyledElement.Polygon;
exports.Polyline = createStyledElement.Polyline;
exports.Prefetch = createStyledElement.Prefetch;
exports.RadialGradient = createStyledElement.RadialGradient;
exports.Rect = createStyledElement.Rect;
exports.SetTag = createStyledElement.SetTag;
exports.SolidColor = createStyledElement.SolidColor;
exports.Solidcolor = createStyledElement.Solidcolor;
exports.Stop = createStyledElement.Stop;
exports.Switch = createStyledElement.Switch;
exports.SymbolTag = createStyledElement.SymbolTag;
exports.Tbreak = createStyledElement.Tbreak;
exports.Text = createStyledElement.Text;
exports.TextArea = createStyledElement.TextArea;
exports.TextPath = createStyledElement.TextPath;
exports.Tref = createStyledElement.Tref;
exports.Tspan = createStyledElement.Tspan;
exports.Unknown = createStyledElement.Unknown;
exports.Use = createStyledElement.Use;
exports.View = createStyledElement.View;
exports.Vkern = createStyledElement.Vkern;